==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/template/barnraiser_01/contact.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path;?>css/aroundme_form.css);
-->
</style>


<form action="index.php?amn=core_contact" method="post" name="frm" id="id_frm">


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_contact_report'];?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php 
				if (isset($display) && $display == "report_sent") {
				?>
				<p>
					<?php echo $lang['txt_report_sent'];?><br />
				</p>
				<?php
				}
				else {
				?>
				<p>
					<?php echo $lang['txt_contact_intro'];?><br />			
				</p>
				
				<?php
				if (isset($lang['contact_report_type'])) {
				?>
				<p>
					<label for="id_contact_type"><?php echo $lang['txt_contact_type'];?></label>
					<?php
					foreach ($lang['contact_report_type'] as $key => $i):
					$checked = "";
					if ($key == 1 || ($key == 3 && isset($_REQUEST['contact_report_type']) && $_REQUEST['contact_report_type'] == "abuse_report")) {
						$checked = "checked=\"checked\"";
					}
					?>
					<input type="radio" name="contact_report_type" value="<?php echo $key;?>" <?php echo $checked;?> />&nbsp;<?php echo $i;?>
					<?php
					endforeach;
					?>
					<br />
				</p>				
				<?php }?>
				
				<p>
					<label for="id_message"><?php echo $lang['txt_message'];?></label>
					<textarea name="contact_message" cols="50" rows="6" style="width: 480px;"></textarea></br />
				</p>
				
				<?php
				if (!isset($_SESSION['md5'])) {
				?>
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input type="text" name="reportee_email" class="input1" size="50" value="" /></br />
				</p>
				<?php }?>
				
				<p>
					<label for="id_url"><?php echo $lang['txt_url'];?></label>
					<input type="text" name="contact_url" class="input1" size="50" value="<?php echo $_SERVER['HTTP_REFERER'];?>" /></br />
				</p>
				
				<hr />
					
				<p align="right">
					<input name="send_contact_report" type="submit" class="input_submit" value="<?php echo $lang['sub_send_contact_report'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_maintainers'];?><br />
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['hdr_maintainers_intro'];?>:<br />				
				</p>
				
				<?php
				if (isset($maintainers)) {
					foreach($maintainers as $key => $id): 
						$id_card = $id;
						include("inc/identity.inc.php");
					endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>
</form>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/components/core/template/barnraiser_01/contact.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path;?>css/aroundme_form.css);
-->
</style>


<form action="index.php?amn=core_contact" method="post" name="frm" id="id_frm">


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_contact_report'];?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<?php 
				if (isset($display) && $display == "report_sent") {
				?>
				<p>
					<?php echo $lang['txt_report_sent'];?><br />
				</p>
				<?php
				}
				else {
				?>
				<p>
					<?php echo $lang['txt_contact_intro'];?><br />			
				</p>
				
				<?php
				if (isset($lang['contact_report_type'])) {
				?>
				<p>
					<label for="id_contact_type"><?php echo $lang['txt_contact_type'];?></label>
					<?php
					foreach ($lang['contact_report_type'] as $key => $i):
					$checked = "";
					if ($key == 1 || ($key == 3 && isset($_REQUEST['contact_report_type']) && $_REQUEST['contact_report_type'] == "abuse_report")) {
						$checked = "checked=\"checked\"";
					}
					?>
					<input type="radio" name="contact_report_type" value="<?php echo $key;?>" <?php echo $checked;?> />&nbsp;<?php echo $i;?>
					<?php
					endforeach;
					?>
					<br />
				</p>
				<?php }?>
				
				<p>
					<label for="id_message"><?php echo $lang['txt_message'];?></label>
					<textarea name="contact_message" cols="50" rows="6" style="width: 480px;"></textarea></br />
				</p>
				
				<?php
				if (!isset($_SESSION['md5'])) {
				?>
				<p>
					<label for="id_email"><?php echo $lang['txt_email'];?></label>
					<input type="text" name="reportee_email" class="input1" size="50" value="" /></br />
				</p>
				<?php }?>
				
				<p>
					<label for="id_url"><?php echo $lang['txt_url'];?></label>
					<input type="text" name="contact_url" class="input1" size="50" value="<?php echo $_SERVER['HTTP_REFERER'];?>" /></br />
				</p>
				
				<hr />
					
				<p align="right">
					<input name="send_contact_report" type="submit" class="input_submit" value="<?php echo $lang['sub_send_contact_report'];?>" /><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_maintainers'];?></h1>
			</div>
		</div>

		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['hdr_maintainers_intro'];?>:<br />
				</p>
				
				<?php
				if (isset($maintainers)) {
					foreach($maintainers as $key => $id): 
						$id_card = $id;
						include("inc/identity.inc.php");
					endforeach;
				}
				?>
			</div>
		</div>
	</div>
</div>
</form>
